==> camel-core-2.5-SNAPSHOT-sources.jar: org/apache/camel/management/mbean/ManagedProducer.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.Producer;
import org.springframework.jmx.export.annotation.ManagedAttribute;
import org.springframework.jmx.export.annotation.ManagedResource;

/**
 * @version $Revision: 812040 $
 */
@ManagedResource(description = "Managed Producer")
public class ManagedProducer extends ManagedService {

    private Producer producer;

    public ManagedProducer(CamelContext context, Producer producer) {
        super(context, producer);
        this.producer = producer;
    }

    public Producer getProducer() {
        return producer;
    }

    @ManagedAttribute(description = "Endpoint Uri")
    public String getEndpointUri() {
        return producer.getEndpoint().getEndpointUri();
    }

    @ManagedAttribute(description = "Singleton")
    public boolean isSingleton() {
        return producer.isSingleton();
    }

}

==> camel-core-2.6-SNAPSHOT-sources.jar: org/apache/camel/management/mbean/ManagedProducer.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.Producer;
import org.springframework.jmx.export.annotation.ManagedAttribute;
import org.springframework.jmx.export.annotation.ManagedResource;

/**
 * @version $Revision: 1042949 $
 */
@ManagedResource(description = "Managed Producer")
public class ManagedProducer extends ManagedService {
    private final Producer producer;

    public ManagedProducer(CamelContext context, Producer producer) {
        super(context, producer);
        this.producer = producer;
    }

    public Producer getProducer() {
        return producer;
    }

    @ManagedAttribute(description = "Endpoint Uri")
    public String getEndpointUri() {
        return producer.getEndpoint().getEndpointUri();
    }

    @ManagedAttribute(description = "Singleton")
    public boolean isSingleton() {
        return producer.isSingleton();
    }

}
